@@ -2,6 +2,7 @@ package DBIx::Class::Async::ResultSet::Pager;
 
 use strict;
 use warnings;
+use Carp;
 use Future;
 use POSIX qw(ceil);
 
@@ -11,12 +12,10 @@ DBIx::Class::Async::ResultSet::Pager - Asynchronous pagination handling for Asyn
 
 =head1 VERSION
 
-Version 0.49
+Version 0.50
 
 =cut
 
-our $VERSION = '0.49';
-
 =head1 SYNOPSIS
 
     # Obtain a pager from a paged ResultSet
@@ -81,6 +80,22 @@ sub new {
 
 =head1 METHODS
 
+=cut
+
+sub has_next {
+    my $self = shift;
+    # If next_page returns a number (2, 3, etc), this becomes true.
+    # If it returns undef, it stays false.
+    return $self->next_page ? 1 : 0;
+}
+
+sub has_previous {
+    my $self = shift;
+    return $self->previous_page ? 1 : 0;
+}
+
+
+
 =head2 total_entries
 
 Returns a L<Future> that resolves to the total number of entries matching the
@@ -130,7 +145,10 @@ been resolved. If not, it defaults to 1.
 
 sub last_page {
     my $self = shift;
-    my $total = $self->{_total_entries} // 0;
+    croak "Pager not initialized. Call ->total_entries first"
+        unless defined $self->{_total_entries};
+
+    my $total = $self->{_total_entries};
     return 1 if $total == 0;
     return ceil($total / $self->{_rows});
 }
